@@ -9,7 +9,7 @@ use Module::Runtime 'use_module';
 use CLI::Osprey::Descriptive;
 
 # ABSTRACT: Role for CLI::Osprey applications
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 
 sub _osprey_option_to_getopt {
@@ -199,7 +199,7 @@ sub new_with_options {
 
   return $self unless $subcommand_class;
 
-  use_module($subcommand_class);
+  use_module($subcommand_class) unless ref $subcommand_class;
 
   return $subcommand_class->new_with_options(
       %params,
@@ -349,7 +349,7 @@ CLI::Osprey::Role - Role for CLI::Osprey applications
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
